/*
 * Copyright (C) 2011 Sébastien Villemot <sebastien.villemot@ens.fr>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <cmath>

#include "ModelSpec.hh"

ModelSpec::ModelSpec(int ny_arg, int nx_arg, int ns_arg, int nf_arg)
  : ny(ny_arg), nx(nx_arg), ns(ns_arg), nf(nf_arg)
{
}

ModelSpec::~ModelSpec()
{
}

double
ModelSpec::max_error(const gsl_vector *y_prev, const gsl_vector *y_curr, const gsl_vector *fwd, const gsl_vector *shocks) const
{
  gsl_vector *errs = gsl_vector_alloc(ny);
  errors(y_prev, y_curr, fwd, shocks, errs);

  double max_err = NAN;
  for(int i = 0; i < ny; i++)
    {
      double e = log10(fabs(gsl_vector_get(errs, i)));
      if (std::isnan(max_err) || e > max_err)
        max_err = e;
    }
  gsl_vector_free(errs);
  return max_err;
}
