#!/bin/sh

set -e

# Adjust the following paths if necessary
DYNARE_PREPROCESSOR=/usr/lib/dynare/matlab/dynare_m
DYNARE_PLUS_PLUS=dynare++
OCTAVE=octave

if test "x$1" = "x"
then
    echo "$0: you must give the numbers of countries as first argument"
    exit 1
fi

if test "x$2" = "x"
then
    echo "$0: you must give the order of approximation as second argument"
    exit 1
fi

cat > config.mod <<EOF
@#define N = ${1}
EOF

$DYNARE_PREPROCESSOR MC-RBC-A2.mod onlymacro nolinemacro savemacro=MC-RBC-A2-tmp.mod

$DYNARE_PLUS_PLUS --per 0 --sim 0 --no-irfs --order ${2} --no-centralize --threads 8 MC-RBC-A2-tmp.mod

# The MAT files generated by Dynare++ are not readable by MatIO
# Fix them using Octave
cat > fix_mat_format.m <<EOF
load MC-RBC-A2-tmp.mat
command="save -mat MC-RBC-A2-tmp.mat dyn_ss dyn_g_0 dyn_g_1"
if ${2} >= 2
  command = [ command " dyn_g_2" ];
endif
if ${2} == 3
  command = [ command " dyn_g_3" ];
endif
eval(command);
EOF

$OCTAVE --norc --no-history fix_mat_format.m

mv MC-RBC-A2-tmp.mat MC-RBC-A2-N${1}-O${2}.mat
rm MC-RBC-A2-tmp* fix_mat_format.m config.mod
