## Creates table 3 (maximum differences across simulated series)

source("interface.R")

## Number of countries
N <- 2

specs <- character()

series <- list()

for (o in 1:3)
  for (m in c("per", "hyb"))
    {
      s <- multi.country.solution(n = N, solution.method = m, order = o)$sol
      v <- accuracy.test2(s)

      spec <- paste(m, o, sep = "")
      specs <- c(specs, spec)
      
      series[[spec]] <- t(v$data[1:(4*N), ])
    }

## Case of CGA
s <- multi.country.solution(n = N, solution.method = "cga")$sol
v <- accuracy.test2(s)
specs <- c(specs, "cga")
series[["cga"]] <- t(v$data[1:(4*N), ])


matrices <- list()

for (v in colnames(series[[1]]))
  {
    m <- matrix(NA, length(specs)-1, length(specs)-1)
    for (i in 2:length(specs))
      for (j in 1:(i-1))
        {
          s1 <- series[[specs[i]]][, v]
          s2 <- series[[specs[j]]][, v]
          m[i-1, j] <- max(abs((s1-s2)/s2))
          rownames(m) <- specs[2:length(specs)]
          colnames(m) <- specs[1:(length(specs)-1)]
        }
    matrices[[v]] <- m
  }

sink("table-series-deviations.tex")

cat("\\documentclass{article}", fill = TRUE)
cat("\\begin{document}", fill = TRUE)

cat("\\begin{tabular}{lrrrrrr}", fill = TRUE)
cat("\\hline\\hline", fill = TRUE)

cat("Variable & ", paste(colnames(matrices[[1]]), collapse = " & "), "\\\\", fill = TRUE)
cat("\\hline\\hline", fill = TRUE)

for (v in names(matrices))
  {
    cat("\\multicolumn{7}{l}{$", v, "$} \\\\", fill = TRUE)
    for (s in rownames(matrices[[v]]))
      {
        cat(s)
        for (s2 in colnames(matrices[[v]]))
          {
            cat(" & ")
            if (!is.na(matrices[[v]][s,s2]))
              cat(formatC(log10(matrices[[v]][s,s2]), format = "f", digits = 2))
          }
        cat(" \\\\", fill = TRUE)
      }
    cat("\\hline", fill = TRUE)
  }

cat("\\end{tabular}", fill = TRUE)

cat("\\end{document}", fill = TRUE)

sink()
